function [residual, g1, g2, g3] = cycle_irf_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(60, 1);
T53 = params(2)*exp(y(79))/exp(y(48));
T112 = exp(y(54))*exp(y(20))^params(20)*exp(y(1))^params(10);
T116 = exp(y(10))^(1-params(10));
T130 = exp(y(38));
T134 = 1/(2*params(15)*exp(y(36)))*T130*exp(y(41));
T156 = y(63)*exp(y(44))*exp(y(21))/(1-exp(y(21)));
T194 = params(2)*(1-params(13))*exp(y(79))/exp(y(48));
T219 = exp(.5*(params(14)-exp(y(36)))/(exp(y(36))*params(15)*params(14)));
T239 = 1/T130*exp(y(29))/exp(y(36));
T259 = y(63)*exp(y(36))*exp(y(44))*exp(y(21))/(1-exp(y(21)));
T274 = 1-params(12)/2*y(33)^2;
T293 = exp(y(14))/exp(y(2));
T296 = exp(y(32))*(T274-params(12)*y(33)*T293);
T303 = exp(y(69))/exp(y(14));
T306 = exp(y(74))*T53*params(12)*y(75)*T303^2;
T352 = exp(y(79))/exp(y(48))*params(2)*(1-params(5))*(1-params(13))*exp(y(18));
T354 = exp(y(72))*(1-exp(y(70)))*T352;
T362 = exp(y(44))*exp(y(37))/exp(y(16));
T410 = params(20)*params(9)^2;
T420 = (-0.5)*params(11)^0.5*exp(params(20)*0.5*(2*params(8)+T410)/(1-2*params(10)+params(10)^2));
T436 = 0.7071067811865475/params(9)*(params(8)+T410+(-log(exp(y(15))))+params(10)*log(exp(y(15)))-params(10)*params(8))/((-1)+params(10));
T456 = exp(params(10)*params(8)*(-params(20))/((-1)+params(10))^2);
T458 = T420*(erf(T436)-erf(0.7071067811865475*(params(8)+T410+(-10000000000)+params(10)*10000000000-params(10)*params(8))/params(9)/((-1)+params(10))))*T456/params(11)^0.5;
T478 = exp(y(42))*(1-params(10))*exp(y(31))/exp(y(10));
T481 = exp(y(15))/exp(y(20));
T490 = exp(y(42))*params(10)*exp(y(31))/exp(y(1));
T667 = (-(exp(y(14))*exp(y(2))))/(exp(y(2))*exp(y(2)));
T750 = (-(((1-exp(y(21)))*y(63)*exp(y(44))*exp(y(21))-y(63)*exp(y(44))*exp(y(21))*(-exp(y(21))))/((1-exp(y(21)))*(1-exp(y(21))))));
T857 = (-(params(2)*exp(y(79))*exp(y(48))))/(exp(y(48))*exp(y(48)));
T862 = (-(exp(y(79))*exp(y(48))))/(exp(y(48))*exp(y(48)));
lhs =y(46);
rhs =log(exp(y(9)));
residual(1)= lhs-rhs;
lhs =y(47);
rhs =y(46)+params(2)*y(78);
residual(2)= lhs-rhs;
residual(3) = (-exp(y(44)))+(1-params(5))*(1-exp(y(21)))*exp(y(7))+(1-params(5))*(1-exp(y(21)))*exp(y(3))*exp(y(6));
residual(4) = (-params(17))/exp(y(16))+(1-params(5))*(1-params(13))*T53*((1-exp(y(70)))*exp(y(71))-exp(y(70))*y(63));
residual(5) = (-exp(y(50)))+exp(y(28))-params(17)/exp(y(16))-y(63);
residual(6) = (-exp(y(25)))+(1-params(6))/params(6)*exp(y(26));
residual(7) = (-exp(y(28)))+exp(y(12))-params(6)*(exp(y(22))-exp(y(50)));
residual(8) = (-exp(y(42)))+T112*T116;
residual(9) = (-exp(y(65)))+T134;
residual(10) = exp(y(65))+(-exp(y(35)))+T130*exp(y(41))-exp(y(44))*exp(y(12))-params(17)*exp(y(43))-exp(y(23))*exp(y(45))-T156;
residual(11) = (-exp(y(34)))+params(18)+y(64)+params(17)*(exp(y(43))+exp(y(44))/exp(y(16)));
residual(12) = (-exp(y(41)))+exp(y(42))/exp(y(36));
residual(13) = (-exp(y(66)))+exp(y(40))-1;
residual(14) = (-exp(y(31)))+T130/exp(y(40))*(1+exp(y(66)));
residual(15) = (-exp(y(34)))+T194*(exp(y(76))+exp(y(77)));
residual(16) = (-exp(y(36)))+(1-params(13))*(exp(y(4))+exp(y(5)));
residual(17) = (-1)+T130*T219;
residual(18) = (-exp(y(40)))+exp(y(39))/(exp(y(39))-1);
residual(19) = (-exp(y(39)))+1+params(15)*exp(y(36));
residual(20) = (-exp(y(41)))+T239;
residual(21) = (-exp(y(29)))+exp(y(52))+exp(y(14))+params(17)*exp(y(11))+(params(18)+y(64))*exp(y(37))+T259;
residual(22) = (-exp(y(13)))+exp(y(1))*(1-params(19))+exp(y(14))*T274;
residual(23) = (-exp(y(32)))+T53*(exp(y(73))+(1-params(19))*exp(y(74)));
residual(24) = (-1)+T296+T306;
residual(25) = T293-y(33)-1;
residual(26) = (1-params(5))*(1-params(13))*T53*((1-exp(y(70)))*exp(y(71))-exp(y(70))*y(80))+exp(y(22))-exp(y(24))-exp(y(12));
residual(27) = (1-params(5))*(1-params(13))*T53*(1-exp(y(70)))*exp(y(72))+exp(y(12))-exp(y(26))-exp(y(27));
residual(28) = (-exp(y(68)))-y(62)/params(23);
residual(29) = y(62)+(-exp(y(27)))+params(23)*(1+exp(y(68)))+T354;
residual(30) = (-exp(y(11)))+exp(y(43))*(exp(y(36))+exp(y(37)))+T362;
residual(31) = (-exp(y(44)))+exp(y(10))/exp(y(36));
residual(32) = (-exp(y(45)))+exp(y(1))/exp(y(36));
residual(33) = (-exp(y(17)))+params(16)*exp(y(11))^(1-params(7))*exp(y(19))^params(7);
residual(34) = 1-exp(y(19))-exp(y(10));
residual(35) = (-exp(y(18)))+exp(y(17))/exp(y(19));
residual(36) = (-exp(y(16)))+exp(y(17))/exp(y(11));
residual(37) = (-exp(y(49)))+T458/(1-exp(y(21)));
residual(38) = (-exp(y(20)))+exp(y(49))^((1-params(10))/params(20));
residual(39) = (-exp(y(21)))+0.5+0.5*erf(log(exp(y(15)))/(params(9)*1.414213562373095));
residual(40) = (-exp(y(22)))+T478;
residual(41) = (-exp(y(50)))+exp(y(22))*T481^params(21);
residual(42) = (-exp(y(23)))+T490;
residual(43) = y(63)+(-exp(y(25)))+exp(y(24));
residual(44) = exp(y(23))-exp(y(30));
residual(45) = exp(y(9))-exp(y(52))-params(23)*(1+exp(y(68)))*(1-exp(y(10)));
residual(46) = (-exp(y(48)))+exp(y(9))^(-params(1));
residual(47) = (-y(54))+params(3)*y(8)-x(it_, 1);
residual(48) = (-y(62))+params(69);
residual(49) = (-y(63))+params(70);
residual(50) = (-y(64))+params(71);
residual(51) = (1-exp(y(21)))*(1-params(5))*params(13)+(1-params(5))*exp(y(21))+params(5)-exp(y(51));
residual(52) = T130*exp(y(41))-exp(y(67))-exp(y(44))*exp(y(12))-params(17)*exp(y(43))-exp(y(23))*exp(y(45))-T156;
residual(53) = (-exp(y(55)))+exp(y(12))*exp(y(10))+exp(y(1))*exp(y(30))+exp(y(36))*exp(y(67));
residual(54) = (params(18)+y(64))*exp(y(37))-exp(y(53));
residual(55) = (-exp(y(56)))+exp(y(55))/T130;
residual(56) = (-exp(y(57)))+exp(y(52))/T130;
residual(57) = (-exp(y(58)))+exp(y(14))/T130;
residual(58) = (-exp(y(60)))+exp(y(12))/T130;
residual(59) = (-exp(y(61)))+exp(y(9))/T130;
residual(60) = (-exp(y(59)))+exp(y(53))/T130;
if nargout >= 2,
  g1 = zeros(60, 81);

  %
  % Jacobian matrix
  %

  g1(1,9)=(-1);
  g1(1,46)=1;
  g1(2,46)=(-1);
  g1(2,47)=1;
  g1(2,78)=(-params(2));
  g1(3,3)=(1-params(5))*(1-exp(y(21)))*exp(y(3))*exp(y(6));
  g1(3,21)=exp(y(7))*(1-params(5))*(-exp(y(21)))+exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(21)));
  g1(3,6)=(1-params(5))*(1-exp(y(21)))*exp(y(3))*exp(y(6));
  g1(3,7)=(1-params(5))*(1-exp(y(21)))*exp(y(7));
  g1(3,44)=(-exp(y(44)));
  g1(4,16)=(-((-params(17))*exp(y(16))))/(exp(y(16))*exp(y(16)));
  g1(4,70)=(1-params(5))*(1-params(13))*T53*(exp(y(71))*(-exp(y(70)))-exp(y(70))*y(63));
  g1(4,71)=(1-params(5))*(1-params(13))*T53*(1-exp(y(70)))*exp(y(71));
  g1(4,48)=((1-exp(y(70)))*exp(y(71))-exp(y(70))*y(63))*(1-params(5))*(1-params(13))*T857;
  g1(4,79)=(1-params(5))*(1-params(13))*T53*((1-exp(y(70)))*exp(y(71))-exp(y(70))*y(63));
  g1(4,63)=(1-params(5))*(1-params(13))*T53*(-exp(y(70)));
  g1(5,16)=(-((-(params(17)*exp(y(16))))/(exp(y(16))*exp(y(16)))));
  g1(5,28)=exp(y(28));
  g1(5,50)=(-exp(y(50)));
  g1(5,63)=(-1);
  g1(6,25)=(-exp(y(25)));
  g1(6,26)=(1-params(6))/params(6)*exp(y(26));
  g1(7,12)=exp(y(12));
  g1(7,22)=(-(params(6)*exp(y(22))));
  g1(7,28)=(-exp(y(28)));
  g1(7,50)=(-((-exp(y(50)))*params(6)));
  g1(8,10)=T112*exp(y(10))*getPowerDeriv(exp(y(10)),1-params(10),1);
  g1(8,1)=T116*exp(y(54))*exp(y(20))^params(20)*exp(y(1))*getPowerDeriv(exp(y(1)),params(10),1);
  g1(8,20)=T116*exp(y(1))^params(10)*exp(y(54))*exp(y(20))*getPowerDeriv(exp(y(20)),params(20),1);
  g1(8,42)=(-exp(y(42)));
  g1(8,54)=T112*T116;
  g1(9,36)=exp(y(41))*T130*(-(2*params(15)*exp(y(36))))/(2*params(15)*exp(y(36))*2*params(15)*exp(y(36)));
  g1(9,38)=T134;
  g1(9,41)=T134;
  g1(9,65)=(-exp(y(65)));
  g1(10,12)=(-(exp(y(44))*exp(y(12))));
  g1(10,21)=T750;
  g1(10,23)=(-(exp(y(23))*exp(y(45))));
  g1(10,35)=(-exp(y(35)));
  g1(10,38)=T130*exp(y(41));
  g1(10,41)=T130*exp(y(41));
  g1(10,43)=(-(params(17)*exp(y(43))));
  g1(10,44)=(-(exp(y(44))*exp(y(12))))-T156;
  g1(10,45)=(-(exp(y(23))*exp(y(45))));
  g1(10,63)=(-(exp(y(44))*exp(y(21))/(1-exp(y(21)))));
  g1(10,65)=exp(y(65));
  g1(11,16)=params(17)*(-(exp(y(44))*exp(y(16))))/(exp(y(16))*exp(y(16)));
  g1(11,34)=(-exp(y(34)));
  g1(11,43)=params(17)*exp(y(43));
  g1(11,44)=params(17)*exp(y(44))/exp(y(16));
  g1(11,64)=1;
  g1(12,36)=(-(exp(y(42))*exp(y(36))))/(exp(y(36))*exp(y(36)));
  g1(12,41)=(-exp(y(41)));
  g1(12,42)=exp(y(42))/exp(y(36));
  g1(13,40)=exp(y(40));
  g1(13,66)=(-exp(y(66)));
  g1(14,31)=(-exp(y(31)));
  g1(14,38)=T130/exp(y(40))*(1+exp(y(66)));
  g1(14,40)=(1+exp(y(66)))*(-(T130*exp(y(40))))/(exp(y(40))*exp(y(40)));
  g1(14,66)=exp(y(66))*T130/exp(y(40));
  g1(15,34)=(-exp(y(34)));
  g1(15,76)=T194*exp(y(76));
  g1(15,77)=T194*exp(y(77));
  g1(15,48)=(exp(y(76))+exp(y(77)))*params(2)*(1-params(13))*T862;
  g1(15,79)=T194*(exp(y(76))+exp(y(77)));
  g1(16,4)=(1-params(13))*exp(y(4));
  g1(16,36)=(-exp(y(36)));
  g1(16,5)=(1-params(13))*exp(y(5));
  g1(17,36)=T130*T219*(exp(y(36))*params(15)*params(14)*(-exp(y(36)))*.5-.5*(params(14)-exp(y(36)))*exp(y(36))*params(15)*params(14))/(exp(y(36))*params(15)*params(14)*exp(y(36))*params(15)*params(14));
  g1(17,38)=T130*T219;
  g1(18,39)=(exp(y(39))*(exp(y(39))-1)-exp(y(39))*exp(y(39)))/((exp(y(39))-1)*(exp(y(39))-1));
  g1(18,40)=(-exp(y(40)));
  g1(19,36)=params(15)*exp(y(36));
  g1(19,39)=(-exp(y(39)));
  g1(20,29)=T239;
  g1(20,36)=(-(exp(y(36))*1/T130*exp(y(29))))/(exp(y(36))*exp(y(36)));
  g1(20,38)=exp(y(29))*(-T130)/(T130*T130)/exp(y(36));
  g1(20,41)=(-exp(y(41)));
  g1(21,11)=params(17)*exp(y(11));
  g1(21,14)=exp(y(14));
  g1(21,21)=((1-exp(y(21)))*y(63)*exp(y(36))*exp(y(44))*exp(y(21))-y(63)*exp(y(36))*exp(y(44))*exp(y(21))*(-exp(y(21))))/((1-exp(y(21)))*(1-exp(y(21))));
  g1(21,29)=(-exp(y(29)));
  g1(21,36)=T259;
  g1(21,37)=(params(18)+y(64))*exp(y(37));
  g1(21,44)=T259;
  g1(21,52)=exp(y(52));
  g1(21,63)=exp(y(36))*exp(y(44))*exp(y(21))/(1-exp(y(21)));
  g1(21,64)=exp(y(37));
  g1(22,1)=exp(y(1))*(1-params(19));
  g1(22,13)=(-exp(y(13)));
  g1(22,14)=exp(y(14))*T274;
  g1(22,33)=exp(y(14))*(-(params(12)/2*2*y(33)));
  g1(23,73)=T53*exp(y(73));
  g1(23,32)=(-exp(y(32)));
  g1(23,74)=T53*(1-params(19))*exp(y(74));
  g1(23,48)=(exp(y(73))+(1-params(19))*exp(y(74)))*T857;
  g1(23,79)=T53*(exp(y(73))+(1-params(19))*exp(y(74)));
  g1(24,2)=exp(y(32))*(-(params(12)*y(33)*T667));
  g1(24,14)=exp(y(32))*(-(params(12)*y(33)*T293))+exp(y(74))*T53*params(12)*y(75)*(-(exp(y(14))*exp(y(69))))/(exp(y(14))*exp(y(14)))*2*T303;
  g1(24,69)=exp(y(74))*T53*params(12)*y(75)*T303*2*T303;
  g1(24,32)=T296;
  g1(24,74)=T306;
  g1(24,33)=exp(y(32))*((-(params(12)/2*2*y(33)))-params(12)*T293);
  g1(24,75)=exp(y(74))*T53*params(12)*T303^2;
  g1(24,48)=y(75)*T303^2*exp(y(74))*params(12)*T857;
  g1(24,79)=T306;
  g1(25,2)=T667;
  g1(25,14)=T293;
  g1(25,33)=(-1);
  g1(26,12)=(-exp(y(12)));
  g1(26,70)=(1-params(5))*(1-params(13))*T53*(exp(y(71))*(-exp(y(70)))-exp(y(70))*y(80));
  g1(26,22)=exp(y(22));
  g1(26,24)=(-exp(y(24)));
  g1(26,71)=(1-params(5))*(1-params(13))*T53*(1-exp(y(70)))*exp(y(71));
  g1(26,48)=((1-exp(y(70)))*exp(y(71))-exp(y(70))*y(80))*(1-params(5))*(1-params(13))*T857;
  g1(26,79)=(1-params(5))*(1-params(13))*T53*((1-exp(y(70)))*exp(y(71))-exp(y(70))*y(80));
  g1(26,80)=(1-params(5))*(1-params(13))*T53*(-exp(y(70)));
  g1(27,12)=exp(y(12));
  g1(27,70)=exp(y(72))*(1-params(5))*(1-params(13))*T53*(-exp(y(70)));
  g1(27,26)=(-exp(y(26)));
  g1(27,72)=(1-params(5))*(1-params(13))*T53*(1-exp(y(70)))*exp(y(72));
  g1(27,27)=(-exp(y(27)));
  g1(27,48)=exp(y(72))*(1-exp(y(70)))*(1-params(5))*(1-params(13))*T857;
  g1(27,79)=(1-params(5))*(1-params(13))*T53*(1-exp(y(70)))*exp(y(72));
  g1(28,62)=(-(1/params(23)));
  g1(28,68)=(-exp(y(68)));
  g1(29,18)=T354;
  g1(29,70)=exp(y(72))*T352*(-exp(y(70)));
  g1(29,72)=T354;
  g1(29,27)=(-exp(y(27)));
  g1(29,48)=exp(y(72))*(1-exp(y(70)))*exp(y(18))*params(2)*(1-params(5))*(1-params(13))*T862;
  g1(29,79)=T354;
  g1(29,62)=1;
  g1(29,68)=exp(y(68))*params(23);
  g1(30,11)=(-exp(y(11)));
  g1(30,16)=(-(exp(y(16))*exp(y(44))*exp(y(37))))/(exp(y(16))*exp(y(16)));
  g1(30,36)=exp(y(36))*exp(y(43));
  g1(30,37)=T362+exp(y(43))*exp(y(37));
  g1(30,43)=exp(y(43))*(exp(y(36))+exp(y(37)));
  g1(30,44)=T362;
  g1(31,10)=exp(y(10))/exp(y(36));
  g1(31,36)=(-(exp(y(10))*exp(y(36))))/(exp(y(36))*exp(y(36)));
  g1(31,44)=(-exp(y(44)));
  g1(32,1)=exp(y(1))/exp(y(36));
  g1(32,36)=(-(exp(y(1))*exp(y(36))))/(exp(y(36))*exp(y(36)));
  g1(32,45)=(-exp(y(45)));
  g1(33,11)=exp(y(19))^params(7)*params(16)*exp(y(11))*getPowerDeriv(exp(y(11)),1-params(7),1);
  g1(33,17)=(-exp(y(17)));
  g1(33,19)=params(16)*exp(y(11))^(1-params(7))*exp(y(19))*getPowerDeriv(exp(y(19)),params(7),1);
  g1(34,10)=(-exp(y(10)));
  g1(34,19)=(-exp(y(19)));
  g1(35,17)=exp(y(17))/exp(y(19));
  g1(35,18)=(-exp(y(18)));
  g1(35,19)=(-(exp(y(17))*exp(y(19))))/(exp(y(19))*exp(y(19)));
  g1(36,11)=(-(exp(y(11))*exp(y(17))))/(exp(y(11))*exp(y(11)));
  g1(36,16)=(-exp(y(16)));
  g1(36,17)=exp(y(17))/exp(y(11));
  g1(37,15)=T456*T420*0.7071067811865475/params(9)*((-1)+params(10))/((-1)+params(10))*2/(exp(T436^2)*1.772453850905516)/params(11)^0.5/(1-exp(y(21)));
  g1(37,21)=(-(T458*(-exp(y(21)))))/((1-exp(y(21)))*(1-exp(y(21))));
  g1(37,49)=(-exp(y(49)));
  g1(38,20)=(-exp(y(20)));
  g1(38,49)=exp(y(49))*getPowerDeriv(exp(y(49)),(1-params(10))/params(20),1);
  g1(39,15)=0.5*1/(params(9)*1.414213562373095)*2/(1.772453850905516*exp((log(exp(y(15)))/(params(9)*1.414213562373095))^2));
  g1(39,21)=(-exp(y(21)));
  g1(40,10)=(-(exp(y(10))*exp(y(42))*(1-params(10))*exp(y(31))))/(exp(y(10))*exp(y(10)));
  g1(40,22)=(-exp(y(22)));
  g1(40,31)=T478;
  g1(40,42)=T478;
  g1(41,15)=exp(y(22))*T481*getPowerDeriv(T481,params(21),1);
  g1(41,20)=exp(y(22))*getPowerDeriv(T481,params(21),1)*(-(exp(y(20))*exp(y(15))))/(exp(y(20))*exp(y(20)));
  g1(41,22)=exp(y(22))*T481^params(21);
  g1(41,50)=(-exp(y(50)));
  g1(42,1)=(-(exp(y(1))*exp(y(42))*params(10)*exp(y(31))))/(exp(y(1))*exp(y(1)));
  g1(42,23)=(-exp(y(23)));
  g1(42,31)=T490;
  g1(42,42)=T490;
  g1(43,24)=exp(y(24));
  g1(43,25)=(-exp(y(25)));
  g1(43,63)=1;
  g1(44,23)=exp(y(23));
  g1(44,30)=(-exp(y(30)));
  g1(45,9)=exp(y(9));
  g1(45,10)=(-(params(23)*(1+exp(y(68)))*(-exp(y(10)))));
  g1(45,52)=(-exp(y(52)));
  g1(45,68)=(-((1-exp(y(10)))*exp(y(68))*params(23)));
  g1(46,9)=exp(y(9))*getPowerDeriv(exp(y(9)),(-params(1)),1);
  g1(46,48)=(-exp(y(48)));
  g1(47,8)=params(3);
  g1(47,54)=(-1);
  g1(47,81)=(-1);
  g1(48,62)=(-1);
  g1(49,63)=(-1);
  g1(50,64)=(-1);
  g1(51,21)=(1-params(5))*exp(y(21))+(-exp(y(21)))*(1-params(5))*params(13);
  g1(51,51)=(-exp(y(51)));
  g1(52,12)=(-(exp(y(44))*exp(y(12))));
  g1(52,21)=T750;
  g1(52,23)=(-(exp(y(23))*exp(y(45))));
  g1(52,38)=T130*exp(y(41));
  g1(52,41)=T130*exp(y(41));
  g1(52,43)=(-(params(17)*exp(y(43))));
  g1(52,44)=(-(exp(y(44))*exp(y(12))))-T156;
  g1(52,45)=(-(exp(y(23))*exp(y(45))));
  g1(52,63)=(-(exp(y(44))*exp(y(21))/(1-exp(y(21)))));
  g1(52,67)=(-exp(y(67)));
  g1(53,10)=exp(y(12))*exp(y(10));
  g1(53,12)=exp(y(12))*exp(y(10));
  g1(53,1)=exp(y(1))*exp(y(30));
  g1(53,30)=exp(y(1))*exp(y(30));
  g1(53,36)=exp(y(36))*exp(y(67));
  g1(53,55)=(-exp(y(55)));
  g1(53,67)=exp(y(36))*exp(y(67));
  g1(54,37)=(params(18)+y(64))*exp(y(37));
  g1(54,53)=(-exp(y(53)));
  g1(54,64)=exp(y(37));
  g1(55,38)=(-(T130*exp(y(55))))/(T130*T130);
  g1(55,55)=exp(y(55))/T130;
  g1(55,56)=(-exp(y(56)));
  g1(56,38)=(-(T130*exp(y(52))))/(T130*T130);
  g1(56,52)=exp(y(52))/T130;
  g1(56,57)=(-exp(y(57)));
  g1(57,14)=exp(y(14))/T130;
  g1(57,38)=(-(T130*exp(y(14))))/(T130*T130);
  g1(57,58)=(-exp(y(58)));
  g1(58,12)=exp(y(12))/T130;
  g1(58,38)=(-(exp(y(12))*T130))/(T130*T130);
  g1(58,60)=(-exp(y(60)));
  g1(59,9)=exp(y(9))/T130;
  g1(59,38)=(-(exp(y(9))*T130))/(T130*T130);
  g1(59,61)=(-exp(y(61)));
  g1(60,38)=(-(T130*exp(y(53))))/(T130*T130);
  g1(60,53)=exp(y(53))/T130;
  g1(60,59)=(-exp(y(59)));
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],60,6561);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],60,531441);
end
end
