function [residual, g1, g2] = cycle_irf_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                     columns: variables in declaration order
%                                                     rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 60, 1);

%
% Model equations
%

T25 = 1-exp(y(13));
T46 = params(2)*exp(y(40))/exp(y(40));
T102 = exp(y(46))*exp(y(12))^params(20)*exp(y(5))^params(10);
T106 = exp(y(2))^(1-params(10));
T120 = exp(y(30));
T124 = 1/(2*params(15)*exp(y(28)))*T120*exp(y(33));
T144 = y(55)*exp(y(36))*exp(y(13))/T25;
T199 = exp(.5*(params(14)-exp(y(28)))/(exp(y(28))*params(15)*params(14)));
T219 = 1/T120*exp(y(21))/exp(y(28));
T237 = y(55)*exp(y(28))*exp(y(36))*exp(y(13))/T25;
T250 = 1-params(12)/2*y(25)^2;
T313 = exp(y(36))*exp(y(29))/exp(y(8));
T360 = params(20)*params(9)^2;
T370 = (-0.5)*params(11)^0.5*exp(params(20)*0.5*(2*params(8)+T360)/(1-2*params(10)+params(10)^2));
T385 = 0.7071067811865475/params(9)*(params(8)+T360+(-log(exp(y(7))))+params(10)*log(exp(y(7)))-params(10)*params(8))/((-1)+params(10));
T405 = exp(params(10)*params(8)*(-params(20))/((-1)+params(10))^2);
T407 = T370*(erf(T385)-erf(0.7071067811865475*(params(8)+T360+(-10000000000)+params(10)*10000000000-params(10)*params(8))/params(9)/((-1)+params(10))))*T405/params(11)^0.5;
T428 = exp(y(34))*(1-params(10))*exp(y(23))/exp(y(2));
T431 = exp(y(7))/exp(y(12));
T440 = exp(y(34))*params(10)*exp(y(23))/exp(y(5));
T644 = (-((T25*y(55)*exp(y(36))*exp(y(13))-y(55)*exp(y(36))*exp(y(13))*(-exp(y(13))))/(T25*T25)));
lhs =y(38);
rhs =log(exp(y(1)));
residual(1)= lhs-rhs;
lhs =y(39);
rhs =y(38)+y(39)*params(2);
residual(2)= lhs-rhs;
residual(3) = (-exp(y(36)))+exp(y(36))*(1-params(5))*T25+(1-params(5))*T25*exp(y(8))*exp(y(35));
residual(4) = (-params(17))/exp(y(8))+(1-params(5))*(1-params(13))*T46*(T25*exp(y(16))-exp(y(13))*y(55));
residual(5) = (-exp(y(42)))+exp(y(20))-params(17)/exp(y(8))-y(55);
residual(6) = (-exp(y(17)))+(1-params(6))/params(6)*exp(y(18));
residual(7) = (-exp(y(20)))+exp(y(4))-params(6)*(exp(y(14))-exp(y(42)));
residual(8) = (-exp(y(34)))+T102*T106;
residual(9) = (-exp(y(57)))+T124;
residual(10) = exp(y(57))+(-exp(y(27)))+T120*exp(y(33))-exp(y(36))*exp(y(4))-exp(y(35))*params(17)-exp(y(15))*exp(y(37))-T144;
residual(11) = (-exp(y(26)))+params(18)+y(56)+params(17)*(exp(y(35))+exp(y(36))/exp(y(8)));
residual(12) = (-exp(y(33)))+exp(y(34))/exp(y(28));
residual(13) = (-exp(y(58)))+exp(y(32))-1;
residual(14) = (-exp(y(23)))+T120/exp(y(32))*(1+exp(y(58)));
residual(15) = (-exp(y(26)))+params(2)*(1-params(13))*(exp(y(27))+exp(y(26)));
residual(16) = (-exp(y(28)))+(1-params(13))*(exp(y(28))+exp(y(29)));
residual(17) = (-1)+T120*T199;
residual(18) = (-exp(y(32)))+exp(y(31))/(exp(y(31))-1);
residual(19) = (-exp(y(31)))+1+params(15)*exp(y(28));
residual(20) = (-exp(y(33)))+T219;
residual(21) = (-exp(y(21)))+exp(y(44))+exp(y(6))+params(17)*exp(y(3))+(params(18)+y(56))*exp(y(29))+T237;
residual(22) = (-exp(y(5)))+exp(y(5))*(1-params(19))+exp(y(6))*T250;
residual(23) = (-exp(y(24)))+T46*(exp(y(22))+(1-params(19))*exp(y(24)));
residual(24) = (-1)+exp(y(24))*(T250-params(12)*y(25))+y(25)*exp(y(24))*T46*params(12);
residual(25) = 1-y(25)-1;
residual(26) = (1-params(5))*(1-params(13))*T46*(T25*exp(y(16))-exp(y(13))*y(55))+exp(y(14))-exp(y(16))-exp(y(4));
residual(27) = exp(y(18))*T25*(1-params(5))*(1-params(13))*T46+exp(y(4))-exp(y(18))-exp(y(19));
residual(28) = (-exp(y(60)))-y(54)/params(23);
residual(29) = y(54)+(-exp(y(19)))+params(23)*(1+exp(y(60)))+exp(y(18))*T25*params(2)*(1-params(5))*(1-params(13))*exp(y(10));
residual(30) = (-exp(y(3)))+exp(y(35))*(exp(y(28))+exp(y(29)))+T313;
residual(31) = (-exp(y(36)))+exp(y(2))/exp(y(28));
residual(32) = (-exp(y(37)))+exp(y(5))/exp(y(28));
residual(33) = (-exp(y(9)))+params(16)*exp(y(3))^(1-params(7))*exp(y(11))^params(7);
residual(34) = 1-exp(y(11))-exp(y(2));
residual(35) = (-exp(y(10)))+exp(y(9))/exp(y(11));
residual(36) = (-exp(y(8)))+exp(y(9))/exp(y(3));
residual(37) = (-exp(y(41)))+T407/T25;
residual(38) = (-exp(y(12)))+exp(y(41))^((1-params(10))/params(20));
residual(39) = (-exp(y(13)))+0.5+0.5*erf(log(exp(y(7)))/(params(9)*1.414213562373095));
residual(40) = (-exp(y(14)))+T428;
residual(41) = (-exp(y(42)))+exp(y(14))*T431^params(21);
residual(42) = (-exp(y(15)))+T440;
residual(43) = y(55)+exp(y(16))+(-exp(y(17)));
residual(44) = exp(y(15))-exp(y(22));
residual(45) = exp(y(1))-exp(y(44))-params(23)*(1+exp(y(60)))*(1-exp(y(2)));
residual(46) = (-exp(y(40)))+exp(y(1))^(-params(1));
residual(47) = (-y(46))+y(46)*params(3)-x(1);
residual(48) = (-y(54))+params(69);
residual(49) = (-y(55))+params(70);
residual(50) = (-y(56))+params(71);
residual(51) = T25*(1-params(5))*params(13)+(1-params(5))*exp(y(13))+params(5)-exp(y(43));
residual(52) = T120*exp(y(33))-exp(y(59))-exp(y(36))*exp(y(4))-exp(y(35))*params(17)-exp(y(15))*exp(y(37))-T144;
residual(53) = (-exp(y(47)))+exp(y(4))*exp(y(2))+exp(y(5))*exp(y(22))+exp(y(28))*exp(y(59));
residual(54) = (params(18)+y(56))*exp(y(29))-exp(y(45));
residual(55) = (-exp(y(48)))+exp(y(47))/T120;
residual(56) = (-exp(y(49)))+exp(y(44))/T120;
residual(57) = (-exp(y(50)))+exp(y(6))/T120;
residual(58) = (-exp(y(52)))+exp(y(4))/T120;
residual(59) = (-exp(y(53)))+exp(y(1))/T120;
residual(60) = (-exp(y(51)))+exp(y(45))/T120;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(60, 60);

  %
  % Jacobian matrix
  %

  g1(1,1)=(-1);
  g1(1,38)=1;
  g1(2,38)=(-1);
  g1(2,39)=1-params(2);
  g1(3,8)=(1-params(5))*T25*exp(y(8))*exp(y(35));
  g1(3,13)=exp(y(36))*(1-params(5))*(-exp(y(13)))+exp(y(35))*exp(y(8))*(1-params(5))*(-exp(y(13)));
  g1(3,35)=(1-params(5))*T25*exp(y(8))*exp(y(35));
  g1(3,36)=(-exp(y(36)))+exp(y(36))*(1-params(5))*T25;
  g1(4,8)=(-(exp(y(8))*(-params(17))))/(exp(y(8))*exp(y(8)));
  g1(4,13)=(1-params(5))*(1-params(13))*T46*(exp(y(16))*(-exp(y(13)))-exp(y(13))*y(55));
  g1(4,16)=(1-params(5))*(1-params(13))*T46*T25*exp(y(16));
  g1(4,55)=(1-params(5))*(1-params(13))*T46*(-exp(y(13)));
  g1(5,8)=(-((-(exp(y(8))*params(17)))/(exp(y(8))*exp(y(8)))));
  g1(5,20)=exp(y(20));
  g1(5,42)=(-exp(y(42)));
  g1(5,55)=(-1);
  g1(6,17)=(-exp(y(17)));
  g1(6,18)=(1-params(6))/params(6)*exp(y(18));
  g1(7,4)=exp(y(4));
  g1(7,14)=(-(params(6)*exp(y(14))));
  g1(7,20)=(-exp(y(20)));
  g1(7,42)=(-((-exp(y(42)))*params(6)));
  g1(8,2)=T102*exp(y(2))*getPowerDeriv(exp(y(2)),1-params(10),1);
  g1(8,5)=T106*exp(y(46))*exp(y(12))^params(20)*exp(y(5))*getPowerDeriv(exp(y(5)),params(10),1);
  g1(8,12)=T106*exp(y(5))^params(10)*exp(y(46))*exp(y(12))*getPowerDeriv(exp(y(12)),params(20),1);
  g1(8,34)=(-exp(y(34)));
  g1(8,46)=T102*T106;
  g1(9,28)=exp(y(33))*T120*(-(2*params(15)*exp(y(28))))/(2*params(15)*exp(y(28))*2*params(15)*exp(y(28)));
  g1(9,30)=T124;
  g1(9,33)=T124;
  g1(9,57)=(-exp(y(57)));
  g1(10,4)=(-(exp(y(36))*exp(y(4))));
  g1(10,13)=T644;
  g1(10,15)=(-(exp(y(15))*exp(y(37))));
  g1(10,27)=(-exp(y(27)));
  g1(10,30)=T120*exp(y(33));
  g1(10,33)=T120*exp(y(33));
  g1(10,35)=(-(exp(y(35))*params(17)));
  g1(10,36)=(-(exp(y(36))*exp(y(4))))-T144;
  g1(10,37)=(-(exp(y(15))*exp(y(37))));
  g1(10,55)=(-(exp(y(36))*exp(y(13))/T25));
  g1(10,57)=exp(y(57));
  g1(11,8)=params(17)*(-(exp(y(36))*exp(y(8))))/(exp(y(8))*exp(y(8)));
  g1(11,26)=(-exp(y(26)));
  g1(11,35)=exp(y(35))*params(17);
  g1(11,36)=params(17)*exp(y(36))/exp(y(8));
  g1(11,56)=1;
  g1(12,28)=(-(exp(y(34))*exp(y(28))))/(exp(y(28))*exp(y(28)));
  g1(12,33)=(-exp(y(33)));
  g1(12,34)=exp(y(34))/exp(y(28));
  g1(13,32)=exp(y(32));
  g1(13,58)=(-exp(y(58)));
  g1(14,23)=(-exp(y(23)));
  g1(14,30)=T120/exp(y(32))*(1+exp(y(58)));
  g1(14,32)=(1+exp(y(58)))*(-(T120*exp(y(32))))/(exp(y(32))*exp(y(32)));
  g1(14,58)=exp(y(58))*T120/exp(y(32));
  g1(15,26)=(-exp(y(26)))+exp(y(26))*params(2)*(1-params(13));
  g1(15,27)=exp(y(27))*params(2)*(1-params(13));
  g1(16,28)=(-exp(y(28)))+(1-params(13))*exp(y(28));
  g1(16,29)=(1-params(13))*exp(y(29));
  g1(17,28)=T120*T199*(exp(y(28))*params(15)*params(14)*(-exp(y(28)))*.5-.5*(params(14)-exp(y(28)))*exp(y(28))*params(15)*params(14))/(exp(y(28))*params(15)*params(14)*exp(y(28))*params(15)*params(14));
  g1(17,30)=T120*T199;
  g1(18,31)=(exp(y(31))*(exp(y(31))-1)-exp(y(31))*exp(y(31)))/((exp(y(31))-1)*(exp(y(31))-1));
  g1(18,32)=(-exp(y(32)));
  g1(19,28)=params(15)*exp(y(28));
  g1(19,31)=(-exp(y(31)));
  g1(20,21)=T219;
  g1(20,28)=(-(exp(y(28))*1/T120*exp(y(21))))/(exp(y(28))*exp(y(28)));
  g1(20,30)=exp(y(21))*(-T120)/(T120*T120)/exp(y(28));
  g1(20,33)=(-exp(y(33)));
  g1(21,3)=params(17)*exp(y(3));
  g1(21,6)=exp(y(6));
  g1(21,13)=(T25*y(55)*exp(y(28))*exp(y(36))*exp(y(13))-y(55)*exp(y(28))*exp(y(36))*exp(y(13))*(-exp(y(13))))/(T25*T25);
  g1(21,21)=(-exp(y(21)));
  g1(21,28)=T237;
  g1(21,29)=(params(18)+y(56))*exp(y(29));
  g1(21,36)=T237;
  g1(21,44)=exp(y(44));
  g1(21,55)=exp(y(28))*exp(y(36))*exp(y(13))/T25;
  g1(21,56)=exp(y(29));
  g1(22,5)=(-exp(y(5)))+exp(y(5))*(1-params(19));
  g1(22,6)=exp(y(6))*T250;
  g1(22,25)=exp(y(6))*(-(params(12)/2*2*y(25)));
  g1(23,22)=T46*exp(y(22));
  g1(23,24)=(-exp(y(24)))+T46*(1-params(19))*exp(y(24));
  g1(24,24)=exp(y(24))*(T250-params(12)*y(25))+y(25)*exp(y(24))*T46*params(12);
  g1(24,25)=exp(y(24))*T46*params(12)+exp(y(24))*((-(params(12)/2*2*y(25)))-params(12));
  g1(25,25)=(-1);
  g1(26,4)=(-exp(y(4)));
  g1(26,13)=(1-params(5))*(1-params(13))*T46*(exp(y(16))*(-exp(y(13)))-exp(y(13))*y(55));
  g1(26,14)=exp(y(14));
  g1(26,16)=(1-params(5))*(1-params(13))*T46*T25*exp(y(16))-exp(y(16));
  g1(26,55)=(1-params(5))*(1-params(13))*T46*(-exp(y(13)));
  g1(27,4)=exp(y(4));
  g1(27,13)=exp(y(18))*(1-params(5))*(1-params(13))*T46*(-exp(y(13)));
  g1(27,18)=exp(y(18))*T25*(1-params(5))*(1-params(13))*T46-exp(y(18));
  g1(27,19)=(-exp(y(19)));
  g1(28,54)=(-(1/params(23)));
  g1(28,60)=(-exp(y(60)));
  g1(29,10)=exp(y(18))*T25*params(2)*(1-params(5))*(1-params(13))*exp(y(10));
  g1(29,13)=exp(y(18))*params(2)*(1-params(5))*(1-params(13))*exp(y(10))*(-exp(y(13)));
  g1(29,18)=exp(y(18))*T25*params(2)*(1-params(5))*(1-params(13))*exp(y(10));
  g1(29,19)=(-exp(y(19)));
  g1(29,54)=1;
  g1(29,60)=exp(y(60))*params(23);
  g1(30,3)=(-exp(y(3)));
  g1(30,8)=(-(exp(y(8))*exp(y(36))*exp(y(29))))/(exp(y(8))*exp(y(8)));
  g1(30,28)=exp(y(35))*exp(y(28));
  g1(30,29)=T313+exp(y(35))*exp(y(29));
  g1(30,35)=exp(y(35))*(exp(y(28))+exp(y(29)));
  g1(30,36)=T313;
  g1(31,2)=exp(y(2))/exp(y(28));
  g1(31,28)=(-(exp(y(2))*exp(y(28))))/(exp(y(28))*exp(y(28)));
  g1(31,36)=(-exp(y(36)));
  g1(32,5)=exp(y(5))/exp(y(28));
  g1(32,28)=(-(exp(y(5))*exp(y(28))))/(exp(y(28))*exp(y(28)));
  g1(32,37)=(-exp(y(37)));
  g1(33,3)=exp(y(11))^params(7)*params(16)*exp(y(3))*getPowerDeriv(exp(y(3)),1-params(7),1);
  g1(33,9)=(-exp(y(9)));
  g1(33,11)=params(16)*exp(y(3))^(1-params(7))*exp(y(11))*getPowerDeriv(exp(y(11)),params(7),1);
  g1(34,2)=(-exp(y(2)));
  g1(34,11)=(-exp(y(11)));
  g1(35,9)=exp(y(9))/exp(y(11));
  g1(35,10)=(-exp(y(10)));
  g1(35,11)=(-(exp(y(9))*exp(y(11))))/(exp(y(11))*exp(y(11)));
  g1(36,3)=(-(exp(y(3))*exp(y(9))))/(exp(y(3))*exp(y(3)));
  g1(36,8)=(-exp(y(8)));
  g1(36,9)=exp(y(9))/exp(y(3));
  g1(37,7)=T405*T370*0.7071067811865475/params(9)*((-1)+params(10))/((-1)+params(10))*2/(exp(T385^2)*1.772453850905516)/params(11)^0.5/T25;
  g1(37,13)=(-(T407*(-exp(y(13)))))/(T25*T25);
  g1(37,41)=(-exp(y(41)));
  g1(38,12)=(-exp(y(12)));
  g1(38,41)=exp(y(41))*getPowerDeriv(exp(y(41)),(1-params(10))/params(20),1);
  g1(39,7)=0.5*1/(params(9)*1.414213562373095)*2/(1.772453850905516*exp((log(exp(y(7)))/(params(9)*1.414213562373095))^2));
  g1(39,13)=(-exp(y(13)));
  g1(40,2)=(-(exp(y(2))*exp(y(34))*(1-params(10))*exp(y(23))))/(exp(y(2))*exp(y(2)));
  g1(40,14)=(-exp(y(14)));
  g1(40,23)=T428;
  g1(40,34)=T428;
  g1(41,7)=exp(y(14))*T431*getPowerDeriv(T431,params(21),1);
  g1(41,12)=exp(y(14))*getPowerDeriv(T431,params(21),1)*(-(exp(y(12))*exp(y(7))))/(exp(y(12))*exp(y(12)));
  g1(41,14)=exp(y(14))*T431^params(21);
  g1(41,42)=(-exp(y(42)));
  g1(42,5)=(-(exp(y(5))*exp(y(34))*params(10)*exp(y(23))))/(exp(y(5))*exp(y(5)));
  g1(42,15)=(-exp(y(15)));
  g1(42,23)=T440;
  g1(42,34)=T440;
  g1(43,16)=exp(y(16));
  g1(43,17)=(-exp(y(17)));
  g1(43,55)=1;
  g1(44,15)=exp(y(15));
  g1(44,22)=(-exp(y(22)));
  g1(45,1)=exp(y(1));
  g1(45,2)=(-(params(23)*(1+exp(y(60)))*(-exp(y(2)))));
  g1(45,44)=(-exp(y(44)));
  g1(45,60)=(-((1-exp(y(2)))*exp(y(60))*params(23)));
  g1(46,1)=exp(y(1))*getPowerDeriv(exp(y(1)),(-params(1)),1);
  g1(46,40)=(-exp(y(40)));
  g1(47,46)=(-1)+params(3);
  g1(48,54)=(-1);
  g1(49,55)=(-1);
  g1(50,56)=(-1);
  g1(51,13)=(1-params(5))*exp(y(13))+(-exp(y(13)))*(1-params(5))*params(13);
  g1(51,43)=(-exp(y(43)));
  g1(52,4)=(-(exp(y(36))*exp(y(4))));
  g1(52,13)=T644;
  g1(52,15)=(-(exp(y(15))*exp(y(37))));
  g1(52,30)=T120*exp(y(33));
  g1(52,33)=T120*exp(y(33));
  g1(52,35)=(-(exp(y(35))*params(17)));
  g1(52,36)=(-(exp(y(36))*exp(y(4))))-T144;
  g1(52,37)=(-(exp(y(15))*exp(y(37))));
  g1(52,55)=(-(exp(y(36))*exp(y(13))/T25));
  g1(52,59)=(-exp(y(59)));
  g1(53,2)=exp(y(4))*exp(y(2));
  g1(53,4)=exp(y(4))*exp(y(2));
  g1(53,5)=exp(y(5))*exp(y(22));
  g1(53,22)=exp(y(5))*exp(y(22));
  g1(53,28)=exp(y(28))*exp(y(59));
  g1(53,47)=(-exp(y(47)));
  g1(53,59)=exp(y(28))*exp(y(59));
  g1(54,29)=(params(18)+y(56))*exp(y(29));
  g1(54,45)=(-exp(y(45)));
  g1(54,56)=exp(y(29));
  g1(55,30)=(-(T120*exp(y(47))))/(T120*T120);
  g1(55,47)=exp(y(47))/T120;
  g1(55,48)=(-exp(y(48)));
  g1(56,30)=(-(T120*exp(y(44))))/(T120*T120);
  g1(56,44)=exp(y(44))/T120;
  g1(56,49)=(-exp(y(49)));
  g1(57,6)=exp(y(6))/T120;
  g1(57,30)=(-(T120*exp(y(6))))/(T120*T120);
  g1(57,50)=(-exp(y(50)));
  g1(58,4)=exp(y(4))/T120;
  g1(58,30)=(-(exp(y(4))*T120))/(T120*T120);
  g1(58,52)=(-exp(y(52)));
  g1(59,1)=exp(y(1))/T120;
  g1(59,30)=(-(exp(y(1))*T120))/(T120*T120);
  g1(59,53)=(-exp(y(53)));
  g1(60,30)=(-(T120*exp(y(45))))/(T120*T120);
  g1(60,45)=exp(y(45))/T120;
  g1(60,51)=(-exp(y(51)));
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],60,3600);
end
end
