warning 'off';

close all; clc; 

% clear; 

delete('*.mat','*.pdf', '*.asv','*.fig','*.eps','cacciaFiori.m','cacciaFioriDeterministic.m','*_dynamic.m','*_static.m','*.txt','*.bin',...
       '*.cod', '*.jnl','*.log','*_set_auxiliary_variables.m','cycle_irf.m','cycle_moments.m','transition.m');

addpath C:\dynare\4.4.3\matlab

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% CHOOSE OPTIONS
deterministicI      =      0;                            %% -- set to one if you want transition dynamics following deregulation
                                                                 %  -- otherwise: IRFs/second moments following a productivity shock

reformI             =      1;                            %% -- set to one if you consider a market reform
                                                                 %  -- otherwise: regulation set at euro area level

% momentsI            =      0*(1-deterministicI); %% -- set to one if you want second moments (for given level of regulation);
                                                                 %  -- always zero when considering transition dynamics.
momentsI            =      0;                                                                 
save options deterministicI reformI momentsI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% CHOOSE REFORM
pmrI   = 0; fcI    = 0;  ubI   = 0;  
save reforms ubI fcI pmrI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% CALIBRATE THE MODEL AND GET INITIAL, RIGID STEADY STATE
calibration; 
% clear; 
load options
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if deterministicI==0 && reformI==0 
   %% BUSINES CYCLE DYNAMICS FOR BENCHMARK CALIBRATION WITH HIGH REGULATION (EITHER IRF OR SECOND MOMENTS)
    
   if momentsI==0
      dynare cycle_irf noclearall; load options
   else
      dynare cycle_moments noclearall; load options
      second_moments;
   end    
       clear; 
       load options
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


                          
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if reformI==1 
   %% COMPUTE STEADY STATE AFTER MARKET REFORM   
   newsteady; 
%    clear; 
   
   load options
          
   if deterministicI==0 
      %% BUSINES CYCLE DYNAMICS AFTER DEREGULATION (EITHER IRF OR SECOND MOMENTS)
   
      if momentsI==0
         dynare cycle_irf noclearall; load options
      else
         dynare cycle_moments noclearall; load options
        second_moments;
      end    
             
   else
      %% TRANSITION DYNAMICS AFTER DEREGULATION
       dynare transition noclearall
       


   end
   
end

 %% FOR TRANSITION DYNAMICS WHERE INIT VALUES ARE USED TO GENERATE THE IRFS
% load reforms
% load steadyInitial 
% 
% if pmrI==1
% save steadyInitial_fr c_SSinit u_SSinit ik_SSinit gdpIncome_SSinit markup_SSinit N_SSinit Ne_SSinit fr_SSinit rpD_SSinit yfirm_SSinit
% save pmr_transition_irf c u ikdata ik gdpIncomedata markup N fr rpD iedata yfirm
% end
% 
% if fcI==1
% save steadyInitial_fc c_SSinit u_SSinit ik_SSinit gdpIncome_SSinit markup_SSinit N_SSinit Ne_SSinit fr_SSinit rpD_SSinit yfirm_SSinit
% save fc_transition_irf c u ikdata ik gdpIncomedata markup N Ne fr rpD iedata yfirm
% end 
% 
% if ubI==1
% save steadyInitial_ub c_SSinit u_SSinit ik_SSinit gdpIncome_SSinit markup_SSinit N_SSinit Ne_SSinit fr_SSinit rpD_SSinit yfirm_SSinit
% save ub_transition_irf c u ikdata ik gdpIncomedata markup N Ne fr rpD iedata yfirm
% end
% 
% if pmrI==1 && fcI==1 &&  ubI==1;
% save steadyInitial_joint c_SSinit u_SSinit ik_SSinit gdpIncome_SSinit markup_SSinit N_SSinit Ne_SSinit fr_SSinit rpD_SSinit yfirm_SSinit
% save joint_transition_irf c u ikdata ik gdpIncomedata markup N Ne fr rpD iedata yfirm
% end
 %% FOR CYCLE IRFS
% load reforms
% load steady
% 
% if pmrI==0 && fcI==0 &&  ubI==0;
% save u_SS_transition_EU u_SS
% save epsZ_EU cmdata_epsZ u_epsZ ikdata_epsZ gdpIncomedata_epsZ wdata_epsZ N_epsZ iedata_epsZ markup_epsZ   
% end 
% 
% if pmrI==1 && fcI==1 &&  ubI==1;
% save u_SS_transition_US u_SS
% save epsZ_US cmdata_epsZ u_epsZ ikdata_epsZ gdpIncomedata_epsZ wdata_epsZ N_epsZ iedata_epsZ markup_epsZ   
% end
% 
% if pmrI==1 && fcI==0 &&  ubI==1;
% save u_SS_transition_fcEU u_SS
% save epsZ_fcEU cmdata_epsZ u_epsZ ikdata_epsZ gdpIncomedata_epsZ wdata_epsZ N_epsZ iedata_epsZ markup_epsZ
% end
% 
% if pmrI==0 && fcI==1 &&  ubI==0;
% save u_SS_transition_fcUS u_SS
% save epsZ_fcUS cmdata_epsZ u_epsZ ikdata_epsZ gdpIncomedata_epsZ wdata_epsZ N_epsZ iedata_epsZ markup_epsZ
% end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
